"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
exports.unstable_getServerSession = unstable_getServerSession;

var _core = require("../core");

var _node = require("../utils/node");

async function NextAuthHandler(req, res, options) {
  var _req$headers$xForwar, _options$secret, _options$jwt$secret, _options$jwt;

  const url = (0, _node.getURL)(req.url, options.trustHost, (_req$headers$xForwar = req.headers["x-forwarded-host"]) !== null && _req$headers$xForwar !== void 0 ? _req$headers$xForwar : req.headers.host);
  if (url instanceof Error) return res.status(400).end();
  const request = new Request(url, {
    headers: new Headers(req.headers),
    method: req.method,
    ...(0, _node.getBody)(req)
  });
  (_options$secret = options.secret) !== null && _options$secret !== void 0 ? _options$secret : options.secret = (_options$jwt$secret = (_options$jwt = options.jwt) === null || _options$jwt === void 0 ? void 0 : _options$jwt.secret) !== null && _options$jwt$secret !== void 0 ? _options$jwt$secret : process.env.NEXTAUTH_SECRET;
  const response = await (0, _core.AuthHandler)(request, options);
  res.status(response.status);
  (0, _node.setHeaders)(response.headers, res);
  return res.send(await response.text());
}

function NextAuth(...args) {
  if (args.length === 1) {
    return async (req, res) => await NextAuthHandler(req, res, args[0]);
  }

  return NextAuthHandler(args[0], args[1], args[2]);
}

var _default = NextAuth;
exports.default = _default;
let experimentalWarningShown = false;
let experimentalRSCWarningShown = false;

async function unstable_getServerSession(...args) {
  var _req$headers$xForwar2, _options, _options$secret2, _res$removeHeader, _res;

  if (!experimentalWarningShown && process.env.NODE_ENV !== "production") {
    console.warn("[next-auth][warn][EXPERIMENTAL_API]", "\n`unstable_getServerSession` is experimental and may be removed or changed in the future, as the name suggested.", `\nhttps://next-auth.js.org/configuration/nextjs#unstable_getServerSession}`, `\nhttps://next-auth.js.org/warnings#EXPERIMENTAL_API`);
    experimentalWarningShown = true;
  }

  const isRSC = args.length === 0 || args.length === 1;

  if (!experimentalRSCWarningShown && isRSC && process.env.NODE_ENV !== "production") {
    console.warn("[next-auth][warn][EXPERIMENTAL_API]", "\n`unstable_getServerSession` is used in a React Server Component.", `\nhttps://next-auth.js.org/configuration/nextjs#unstable_getServerSession}`, `\nhttps://next-auth.js.org/warnings#EXPERIMENTAL_API`);
    experimentalRSCWarningShown = true;
  }

  let req, res, options;

  if (isRSC) {
    options = Object.assign({}, args[0], {
      providers: []
    });

    const {
      headers,
      cookies
    } = require("next/headers");

    req = {
      headers: Object.fromEntries(headers()),
      cookies: Object.fromEntries(cookies().getAll().map(c => [c.name, c.value]))
    };
    res = {
      getHeader() {},

      setCookie() {},

      setHeader() {}

    };
  } else {
    req = args[0];
    res = args[1];
    options = Object.assign({}, args[2], {
      providers: []
    });
  }

  const urlOrError = (0, _node.getURL)("/api/auth/session", options.trustHost, (_req$headers$xForwar2 = req.headers["x-forwarded-host"]) !== null && _req$headers$xForwar2 !== void 0 ? _req$headers$xForwar2 : req.headers.host);
  if (urlOrError instanceof Error) throw urlOrError;
  (_options$secret2 = (_options = options).secret) !== null && _options$secret2 !== void 0 ? _options$secret2 : _options.secret = process.env.NEXTAUTH_SECRET;
  const response = await (0, _core.AuthHandler)(new Request(urlOrError, {
    headers: req.headers
  }), options);
  const {
    status = 200,
    headers
  } = response;
  (0, _node.setHeaders)(headers, res);
  (_res$removeHeader = (_res = res).removeHeader) === null || _res$removeHeader === void 0 ? void 0 : _res$removeHeader.call(_res, "Content-Type");
  const data = await response.json();
  if (!data || !Object.keys(data).length) return null;

  if (status === 200) {
    if (isRSC) delete data.expires;
    return data;
  }

  throw new Error(data.message);
}